@@ -5,6 +5,8 @@ import os
 import re
 import logging
 from libs.classes import sequence_unique
+from libs.classes import quality
+from libs.fastq import is_fastq, open_fastq
 
 
 logger = logging.getLogger('seqbuster')
@@ -24,13 +26,13 @@ def prepare(args):
     """
     try:
         f = open(args.dir, 'r')
-        seq_out = open(os.path.join(args.out, "seqs.fa"), 'w')
+        seq_out = open(os.path.join(args.out, "seqs.fastq"), 'w')
         ma_out = open(os.path.join(args.out, "seqs.ma"), 'w')
     except IOError as e:
         logger.error("I/O error({0}): {1}".format(e.errno, e.strerror))
         raise "Can not create output files"
     logger.info("reading sequeces")
-    seq_l, sample_l = _read_fasta_files(f, args)
+    seq_l, sample_l = _read_fastq_files(f, args)
     logger.info("creating matrix with unique sequences")
     _create_matrix_uniq_seq(sample_l, seq_l, ma_out, seq_out)
     logger.info("Finish preprocessing. Get an SAM file of seqs.fa and run seqcluster cluster.")
@@ -60,17 +62,62 @@ def _read_fasta_files(f, args):
             for line in fasta:
                 if line.startswith(">"):
                     idx += 1
-                    counts = re.search("x([0-9]+)", line.strip()).group(1)
+                    counts = int(re.search("x([0-9]+)", line.strip()).group(1))
                 else:
                     seq = line.strip()
-                    seq = seq[0:args.maxl] if len(seq) > args.maxl else seq
-                    if counts > args.minc and len(seq) > args.minl:
+                    seq = seq[0:int(args.maxl)] if len(seq) > int(args.maxl) else seq
+                    if counts > int(args.minc) and len(seq) > int(args.minl):
                         if seq not in seq_l:
                             seq_l[seq] = sequence_unique(idx, seq)
                         seq_l[seq].add_exp(cols[1], counts)
     return seq_l, sample_l
 
 
+def _read_fastq_files(f, args):
+    """ read fasta files of each sample and generate a seq_obj
+    with the information of each unique sequence in each sample
+
+    :param f: file containing the path for each fasta file and
+    the name of the sample. Two column format with `tab` as field
+    separator
+
+    :returns: * :code:`seq_l`: is a list of seq_obj objects, containing
+               the information of each sequence
+             * :code:`sample_l`: is a list with the name of the samples
+               (column two of the config file)
+    """
+    seq_l = {}
+    sample_l = []
+    idx = 1
+    for line1 in f:
+        line1 = line1.strip()
+        cols = line1.split("\t")
+        if not is_fastq(cols[0]):
+            raise ValueError("file is not fastq: %s" % cols[0])
+        with open_fastq(cols[0]) as handle:
+            sample_l.append(cols[1])
+            for line in handle:
+                if line.startswith("@"):
+                    idx += 1
+                    keep = {}
+                    counts = int(re.search("x([0-9]+)", line.strip()).group(1))
+                    seq = handle.next().strip()
+                    handle.next().strip()
+                    qual = handle.next().strip()
+                    seq = seq[0:int(args.maxl)] if len(seq) > int(args.maxl) else seq
+                    qual = qual[0:int(args.maxl)] if len(qual) > int(args.maxl) else qual
+                    if counts > int(args.minc) and len(seq) > int(args.minl):
+                        if seq in keep:
+                            keep[seq].update(qual)
+                        else:
+                            keep[seq] = quality(qual)
+                        if seq not in seq_l:
+                            seq_l[seq] = sequence_unique(idx, seq)
+                        seq_l[seq].add_exp(cols[1], counts)
+                        seq_l[seq].quality = keep[seq].get()
+    return seq_l, sample_l
+
+
 def _create_matrix_uniq_seq(sample_l, seq_l, maout, out):
     """ create matrix counts for each different sequence in all the fasta files
 
@@ -85,12 +132,13 @@ def _create_matrix_uniq_seq(sample_l, seq_l, maout, out):
     for g in sample_l:
         maout.write("\t%s" % g)
     for s in seq_l.keys():
-        maout.write("\n>seq_%s\t%s" % (seq_l[s].idx, seq_l[s].seq))
+        maout.write("\nseq_%s\t%s" % (seq_l[s].idx, seq_l[s].seq))
         for g in sample_l:
-            if seq_l[s].group.has_key(g):
+            if g in seq_l[s].group:
                 maout.write("\t%s" % seq_l[s].group[g])
             else:
                 maout.write("\t0")
-        out.write(">seq_%s\n%s\n" % (seq_l[s].idx, seq_l[s].seq))
+        qual = "".join(seq_l[s].quality)
+        out.write("@seq_%s\n%s\n+\n%s\n" % (seq_l[s].idx, seq_l[s].seq, qual))
     out.close()
     maout.close()
